extern crate macros;

use domain::dto::pageable::PageParams;
use domain::entities::feedback::Feedback;
use domain::{dto::feedback::FeedbackAdd, vo::pageable::Pageable};
use library::context::Context;
use library::extractor::body_extractor::JsonBody;
use library::extractor::path_extractor::PathVar;
use library::extractor::query_extractor::QueryParams;
use library::model::response::ResResult;
use macros::{get, post, route};

use crate::service;

/// 添加反馈信息
#[post("/feedback")]
pub async fn add_feedback(context: Context, JsonBody(req): JsonBody<FeedbackAdd>) -> ResResult<()> {
    service::feedback_service::add_feedback(context, req).await
}

/// 获取反馈信息列表
#[get("/feedback")]
pub async fn get_feedback_list_by_page(
    context: Context,
    QueryParams(page_params): QueryParams<PageParams>,
) -> ResResult<Pageable<Feedback>> {
    service::feedback_service::get_feedback_list_by_page(
        context,
        page_params.page.unwrap(),
        page_params.page_size.unwrap(),
    )
    .await
}

#[route("/feedback/:page/:pageSize", method = ["get", "post"])]
pub async fn get_feedback_list(
    context: Context,
    PathVar(page_params): PathVar<PageParams>,
) -> ResResult<Pageable<Feedback>> {
    service::feedback_service::get_feedback_list_by_page(
        context,
        page_params.page.unwrap(),
        page_params.page_size.unwrap(),
    )
    .await
}
